Estimator
---------

.. autoclass:: pai.estimator.Estimator
   :members:
   :show-inheritance:

.. autoclass:: pai.estimator.AlgorithmEstimator
   :members:
   :show-inheritance:

.. autoclass:: pai.common.configs.UserVpcConfig
   :members:
   :show-inheritance:

.. autoclass:: pai.estimator.FileSystemInput
   :members:
   :show-inheritance:

.. autoclass:: pai.estimator.CpfsFileSystemInput
   :members:
   :show-inheritance:
